<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://fuji-9.com/
 * @since      1.0.0
 *
 * @package    Eus_For_Woocommerce
 * @subpackage Eus_For_Woocommerce/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Eus_For_Woocommerce
 * @subpackage Eus_For_Woocommerce/admin
 * @author     Fuji 9 <info@fuji-9.com>
 */
class Eus_For_Woocommerce_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/eus-for-woocommerce-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/eus-for-woocommerce-admin.js', array( 'jquery' ), $this->version, false );

	}


	/**
	 * Adds custom field on product admin page, under General tab
	 *
	 * @since    1.0.0
	 */
	public function efw_add_custom_general_fields() {
		global $woocommerce, $post;

		//Get chosen one, if exsist
		$selected = get_post_meta( $post->ID, 'eus_prerequisite_purchase', true );

		//Get all products, except current one
		$products = $this->get_all_products($post->ID);
		$products_arr = [];

		//Default one
		$products_arr[-1] = __( 'None', 'eus-for-woocommerce' );

		//Form array with 
		foreach ($products as $key => $product) {
			$products_arr[$product->ID] = $product->post_title;
		}
		?>
		<div class="options_group">
			<?php
			woocommerce_wp_select( 
				array(
					'class'   => 'select short',
					'style'   => '',
					'id'      => 'eus_prerequisite_purchase',
					'name'    => 'eus_prerequisite_purchase',
					'value'   => $selected,
					'label'   => __( 'Prerequisite Purchase', 'eus-for-woocommerce' ), 
					'options' => $products_arr
				)
			);
			?>
		</div>
		<?php
	}


	/**
	 * Saves the value for custom field on product admin page
	 *
	 * @param    integer  $post_id
	 * @since    1.0.0
	 */
	public function efw_add_custom_general_fields_save($post_id) {
		//Get selected value
		$woocommerce_select = $_POST['eus_prerequisite_purchase'];

		if( !empty( $woocommerce_select ) ) {
			update_post_meta( $post_id, 'eus_prerequisite_purchase', esc_attr( $woocommerce_select ) );
		}
		
	}


	/**
	 * Returns all products, except excluded one
	 *
	 * @since    1.0.0
	 * @param    integer  $exclude
	 * @return   array    The name of the plugin.
	 */
	private function get_all_products($exclude) {
		$args = array(
			'post_type' => 'product',
			'posts_per_page' => -1,
			'post__not_in' => array($exclude),
		);
		$products = get_posts( $args );

		return $products;
	}

}
